summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/liboscar/buffer.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/liboscar/buffer.h')
-rw-r--r--kopete/protocols/oscar/liboscar/buffer.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/kopete/protocols/oscar/liboscar/buffer.h b/kopete/protocols/oscar/liboscar/buffer.h
index 900ddb50..b5035b52 100644
--- a/kopete/protocols/oscar/liboscar/buffer.h
+++ b/kopete/protocols/oscar/liboscar/buffer.h
@@ -22,8 +22,8 @@
#include "oscartypes.h"
-#include <qvaluelist.h>
-#include <qcstring.h>
+#include <tqvaluelist.h>
+#include <tqcstring.h>
class QString;
@@ -50,9 +50,9 @@ class Buffer
/**
* \brief Create a prefilled buffer
*
* Constructor that creates a prefilled buffer from the QByteArray \p data
*/
- Buffer( const QByteArray& data );
+ Buffer( const TQByteArray& data );
/** Default destructor */
@@ -72,8 +72,8 @@ class Buffer
/**
* adds the given string to the buffer (make sure it's NULL-terminated)
*/
- int addString(QByteArray);
- int addString(QByteArray, DWORD);
+ int addString(TQByteArray);
+ int addString(TQByteArray, DWORD);
int addString(const char*, DWORD);
int addString(const unsigned char*, DWORD);
@@ -141,9 +141,9 @@ class Buffer
int addLETLV(WORD, WORD, const char *);
/**
* Returns a QString representation of the buffer
*/
- QString toString() const;
+ TQString toString() const;
/**
* gets a DWord out of the buffer
@@ -183,8 +183,8 @@ class Buffer
/**
* Allocates memory for and gets a block of buffer bytes
*/
- QByteArray getBlock(WORD len);
- QByteArray getBBlock(WORD len);
+ TQByteArray getBlock(WORD len);
+ TQByteArray getBBlock(WORD len);
/**
* Allocates memory for and gets a block of buffer words
@@ -194,14 +194,14 @@ class Buffer
/**
* Same as above but returning little-endian
*/
- QCString getLEBlock(WORD len);
+ TQCString getLEBlock(WORD len);
/**
* Convenience function that gets a LNTS (long null terminated string)
* from the buffer. Otherwise you'd need a getWord() + getBlock() call :)
*/
- QCString getLNTS();
- QCString getLELNTS();
+ TQCString getLNTS();
+ TQCString getLELNTS();
/**
* adds a 16-bit long TLV
@@ -231,25 +231,25 @@ class Buffer
/**
* Gets a list of TLV's
*/
- QValueList<TLV> getTLVList();
+ TQValueList<TLV> getTLVList();
/**
* Creates a chat data segment for a tlv and calls addTLV with that data
*/
- int addChatTLV(const WORD, const WORD, const QString &, const WORD);
+ int addChatTLV(const WORD, const WORD, const TQString &, const WORD);
/**
* Similar to the LNTS functions but string is NOT null-terminated
*/
int addBSTR(const char * s);
- QByteArray getBSTR();
- QString peekBSTR();
+ TQByteArray getBSTR();
+ TQString peekBSTR();
int addBUIN(const char * s);
- QByteArray getBUIN();
- QString peekBUIN();
+ TQByteArray getBUIN();
+ TQString peekBUIN();
- operator QByteArray() const;
+ operator TQByteArray() const;
private:
/**
@@ -258,7 +258,7 @@ class Buffer
void expandBuffer(unsigned int inc);
private:
- QByteArray mBuffer;
+ TQByteArray mBuffer;
unsigned int mReadPos;
};
@@ -50,9 +50,9 @@ class Buffer
* \brief Create a prefilled buffer
*
- * Constructor that creates a prefilled buffer from the QByteArray \p data
+ * Constructor that creates a prefilled buffer from the TQByteArray \p data
*/
@@ -141,9 +141,9 @@ class Buffer
int addLETLV(WORD, WORD, const char *);
/**
- * Returns a QString representation of the buffer
+ * Returns a TQString representation of the buffer
*/